@@ -4,7 +4,8 @@
 #' @author Carl Boettiger \email{cboettig@@gmail.com}
 #' @param link the url you wish to add (can be list of urls)
 #' @param article_id the id number of the article 
-#' @param session (optional) the authentication credentials from \code{\link{fs_auth}}. If not provided, will attempt to load from cache as long as authentication has been run.  
+#' @param session (optional) the authentication credentials from \code{\link{fs_auth}}. If not provided, will attempt to load from cache as long as authentication has been run. 
+#' @param debug logical, should function return details of PUT request?
 #' @return output of PUT request (invisibly)
 #' @seealso \code{\link{fs_auth}}
 #' @references \url{http://api.figshare.com}
@@ -14,7 +15,7 @@
 #' fs_add_links(138, list("http://carlboettiger.info", "http://ropensci.org")) 
 #' }
 fs_add_links <- 
-function(article_id, link, session = fs_get_auth()){
+function(article_id, link, session = fs_get_auth(), debug = FALSE){
   
   if(is.list(link)){
     link <- unlist(link)
@@ -22,15 +23,18 @@ function(article_id, link, session = fs_get_auth()){
   
   base <- "http://api.figshare.com/v1"
   method <- paste("my_data/articles", article_id, "links", sep= "/")
-  request <- paste(base, method, sep="/")
+  request <- paste(base, method, sep = "/")
 
   for(i in 1:length(link)){
-    body <- toJSON(list("link"=link[i]))
-    config <- c(verbose(), session, 
+    body <- toJSON(list("link"= link[i]))
+    config <- c(config(token = session), 
                 add_headers("Content-Type" = "application/json"))
-     post <- PUT(request, config=config, body=body)
+     post <- PUT(request, config = config, body = body)
   }
-  invisible(post)
+  if(debug | post$status_code != 200)
+    post
+  else
+    invisible(post)
 }
 
 
