@@ -1,18 +1,25 @@
 
 #' get image url
 #' 
-#' @param id a figshare article id number 
+#' get image url
+#' @param id a (public) figshare figure id number 
+#' @param debug logical, enable debugging mode?
 #' @return a url to the image file
 #' @details this is currently an unstable hack of html parsing
 #' @import XML httr
-fs_image_url <- function(id){
+#' @export 
+fs_image_url <- function(id, debug = FALSE) {
   a <- fs_details(id)
   b <- GET(a$doi)
-  tt <- unlist(xmlToList(parsed_content(b, type="text/html")$children$html))
-  imgs <- grep("\\.png", tt)
-  m <- grep("figshare.com/media", tt[imgs])
-  out <- tt[imgs][m]
-  out
+  if(debug | b$status_code != 200)
+    b
+  else {
+    doc <- htmlParse(content(b, as = "text"))
+    path <- xpathSApply(doc, "//div[@class='filesdownload' and @id='download_all']/a/@href")[[1]]
+#  resp <- GET(path)
+#  if(resp$headers$`content-type` != "image/png")
+    path
+  }
 }
 
 
@@ -22,12 +29,12 @@ fs_image_url <- function(id){
 #' @return a url to the image file
 #' @details use with opts_knit$set(upload.fn = fs_embed)
 #' @export
-fs_embed <- function(file){
+fs_embed <- function(file) {
   ## Read in title, and details from an environment?  from chunk? 
   title <- file 
   description <- "embedded file automatically uploaded to figshare from R"
-  id <- fs_new_article(title, description, type="figure", visibility="public")
+  id <- fs_new_article(title, description, type = "figure", visibility = "public")
   fs_image_url(id)
 }
-
-
+#
+#
